//
// file.cpp
//
// Here we have the main file-functions, including tmp_buf-support
// to detect ambiguous tags
//

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "file.h"
#include "defines.h"

// this is the temporary tag buffer, here is the tag stored if tag_add = 0 and file_write is used
// note: this is needed to detect ambiguous tags, that means tags wich can have parenthesis or not,
//       (known tags so far: fermata, repeatEnd, oct, label)
char     tag_tmp_buf[TAG_LENGTH_MAX]; // temporary tag buffer

FILE* fileWR = 0; // file-stream pointer


// reset the temporary buffer (buffer-length = 0)
void reset_tmp_buf() {
  int i;
  for (i = 0; i < TAG_LENGTH_MAX; i++) tag_tmp_buf[i] = '\0';
}

// check temporary buffer
// note: if there is somthing in the buffer and there are some new tags (tag_add = 1) 
//       then write the buffer to file
int check_tmp_buf(int tag_add, int tab_use, int tab) {
  if (strlen(tag_tmp_buf) > 0 && tag_add) {
    tab -= TAB_LENGTH; // change tab to where it should be
    file_write(tag_tmp_buf, tag_add, tab_use, tab); 
    tab += TAB_LENGTH; // restore old tab
    reset_tmp_buf(); 
  }
  return tab;
}

// file operation: open file (open a file writing stream)
int file_open(const char* filename) {
  return ((fileWR = fopen(filename, "w")) != NULL);
}

// file operation: write buffer to file
int file_write(const char* buffer, int tag_add, int tab_use, int tab) {
  char buf[16]; // temporary buffer, only needed for the blanks (tabs)
  int i = 0;
  int err = 0;  // the return value of fwrite
  
  // if tab_use is set to 'yes' (>=1) write the tab spaces
  if (tab_use) {

    // definition of one tabwidth as space
    sprintf(buf, " ");
  
    // writing the tabulator, the actual tab width is defined in "tab"
    for (i=0; i < tab; i++) {
      if (!tag_add) {
	// do nothing (the old tab should not be changed)
      } else {
	err = fwrite(buf, 1, strlen(buf), fileWR);    
	if (err <= 0) { 
	  printf("ERROR: writing to file failed!\n"); 
	  fflush(stdout); 
	  exit(0);
	}	
      }
    }
  }

  // now, after writing the tabulator, time to write the buffer
  if (!tag_add) {
    strcat(tag_tmp_buf, buffer); // only buffering the tag (needed for detecting ambiguous tags)
  } else {
    err = fwrite(buffer, 1, strlen(buffer), fileWR);
    if (err <= 0) { 
      printf("ERROR: writing to file failed!\n"); 
      fflush(stdout); 
      exit(0);
    }	
  }
  
  return err;
}

// file operation: close file
int file_close() {
    int err = fclose(fileWR);
    if (err < 0) { 
        printf("ERROR: closing file failed!\n"); 
        fflush(stdout); 
        exit(0);
    }	
    fileWR = 0;
    return err;
}
