//
// stack.cpp
//
// This is the dynamic stack, used to store the begin- and end-tags.
// This provides a correct assignment of the tags.
//

#include <stdlib.h>
#include <string.h>
#include "stack.h"

// here is the access of the top element of the stack
static stack_element *stack_top = NULL;

// stack operation: push buffer to stack
// note: the buffer is stored in the allocated memory,
//       stack_top and the next-pointer are updated
int stack_push(char* buffer) {  
  stack_element *stack_ptr;
  
  stack_ptr = (stack_element*) malloc(sizeof(stack_element));  
  if (stack_ptr != NULL) {
    strcpy(stack_ptr->buf, buffer);
    stack_ptr->next = stack_top;
    stack_top = stack_ptr;
  } else return -1; // stack is full, that means no more memory to allocate a stack element

  return 1; // stack operation was successfull
}

// stack operation: get buffer and remove it from stack
// note: the top stack element is removed from memory,
//       after that the pointer stack_top is updated
int stack_pop(char* buffer) {
  stack_element *stack_ptr;
  
  stack_ptr = stack_top;
  if (stack_ptr != NULL) {
    strcpy(buffer, stack_ptr->buf);
    stack_top = (stack_element*) stack_ptr->next;
    free(stack_ptr);
  } else return 0; // stack is empty

  return 1; // stack operation was successfull
}

// stack operation: get buffer from the top element of the stack,
// note: only the top element buffer is copied
int stack_front(char* buffer) {
  
  if (stack_top != NULL) strcpy(buffer, stack_top->buf);
  else return -1; // stack is empty

  return 1; // stack operation was successfull
}
