//
// taglist.cpp
//
// This functions provides the main access to the tags and params stored
// in the stringlists in 'taglist.h'
//

#include "taglist.h"

char tag_buf[TAG_LENGTH_MAX];  // global tag-buffer

// this returns the string at the given position 'pos'
// str is the entry-string (it contains tags and params)
char* getTagPosition(int pos, char* str) {
  char buf[TAG_LENGTH_MAX];
  int i, position = -1, count = 1;
  int len = strlen(str)+1;

  strcpy(buf, str);
  strcat(buf, " "); // add blank to recognice the last param

  for (i = 0; i < len; i++) {
    if (buf[i] == ' ') {
      if (count != pos) {
	while (buf[i] == ' ') i++;
	position = i;
	count++;
      } else {
	strcpy(tag_buf, buf+position);
	tag_buf[i-position] = '\0';
	return tag_buf;
      }
    }
  }
  return NULL;
}

// this provides the first string (the guido-tag)
char* getGuidoTag(char* str) {
  char buf[TAG_LENGTH_MAX];
  int i;
  int len = strlen(str)+1;

  strcpy(buf, str);
  strcat(buf, " "); // add blank to recognice the last param

  for (i = 0; i < len; i++) {
    if (buf[i] == ' ') {
      strcpy(tag_buf, buf);
      tag_buf[i] = '\0';
      return tag_buf;
    }
  }
  return NULL;
}

// this provides the 2nd string (the xml-tag)
char* getXMLTag(char* str) {
  return getTagPosition(2, str);
}

// here we can access to the params (3nd string and above)
char* getParam(int no, char* str) {
  return getTagPosition(no+2, str);
}

// a function for external access
// this searches a guido-tag and return the xml-tag if it matches
char* findGuidoTag(const char*const* tag_class, char *str) {
  char buf[TAG_LENGTH_MAX];
  int i = 0;

  while (strcmp(tag_class[i], "#")) {
    strcpy(buf, tag_class[i]);
    if (!strcmp(getGuidoTag(buf), str)) return getXMLTag(buf);
    i++;
  }

  return NULL;
}

// nearly the same as above, here this function returns the
// param #no of the given guido-tag
char* findGuidoParam(const char*const* tag_class, char *str, int no) {
  char buf[TAG_LENGTH_MAX];
  int i = 0;

  while (strcmp(tag_class[i], "#")) {
    strcpy(buf, tag_class[i]);
    if (!strcmp(getGuidoTag(buf), str)) return getParam(no, buf);
    i++;
  }

  return NULL;
}

// a function for external access
// this searches an xml-tag and return the guido-tag if it matches
char* findXMLTag(const char*const* tag_class, char *str) {
  char buf[TAG_LENGTH_MAX];
  int i = 0;

  while (strcmp(tag_class[i], "#")) {
    strcpy(buf, tag_class[i]);
    if (!strcmp(getXMLTag(buf), str)) return getGuidoTag(buf);
    i++;
  }

  return NULL;
}

// nearly the same as above, here this function returns the
// param #no of the given xml-tag
char* findXMLParam(const char*const* tag_class, char *str, int no) {
  char buf[TAG_LENGTH_MAX];
  int i = 0;

  while (strcmp(tag_class[i], "#")) {
    strcpy(buf, tag_class[i]);
    if (!strcmp(getXMLTag(buf), str)) return getParam(no, buf);
    i++;
  }

  return NULL;
}
